pub enum CommittedCandidateReceiptError {
InvalidCoreIndex,
CoreIndexMismatch {
descriptor: CoreIndex,
commitments: CoreIndex,
},
InvalidSelectedCore,
UmpSignalDecode,
NoAssignment,
UnknownVersion(u8),
TooManyUMPSignals,
DuplicateUMPSignal,
UMPSignalWithV1Descriptor,
NoUMPSignalWithV3Descriptor,
}Expand description
CommittedCandidateReceiptError construction errors.
Variants
InvalidCoreIndex
The specified core index is invalid.
CoreIndexMismatch
The core index in commitments doesn’t match the one in descriptor
Fields
InvalidSelectedCore
The core selector or claim queue offset is invalid.
UmpSignalDecode
Could not decode UMP signal.
NoAssignment
The parachain is not assigned to any core at specified claim queue offset.
UnknownVersion(u8)
Unknown version.
TooManyUMPSignals
The allowed number of UMPSignal messages in the queue was exceeded.
DuplicateUMPSignal
Duplicated UMP signal.
UMPSignalWithV1Descriptor
If the parachain runtime started sending ump signals, v1 descriptors are no longer allowed.
NoUMPSignalWithV3Descriptor
Starting with v3 ump signals are mandatory.
This is to avoid nodes only understanding v1 and v2 to getting tricked into backing a candidate that looks like a valid v1 to them, but is actually an invalid v3.
This is prevented by the runtime rejecting v3 candidates without ump signals. Therefore a candidate that was erroneously backed as v1, while it actually was a v3 would get rejected by the runtime due to missing signals, thus preventing the backer from getting slashed. This is given, because v1 and v2 only nodes would not back a v1 candidate with UMP signals, as that is seen as invalid by them already.