Struct cumulus_primitives_core::relay_chain::CandidateHash [−][src]
pub struct CandidateHash(pub H256);Expand description
Unit type wrapper around [Hash] that represents a candidate hash.
This type is produced by [CandidateReceipt::hash].
This type makes it easy to enforce that a hash is a candidate hash on the type level.
Tuple Fields
0: H256Trait Implementations
Returns the “default value” for a type. Read more
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
If T::size_of is a constant, consider implementing constant_size as well. Read more
Used to optimize MallocSizeOf implementation for collections
like Vec and HashMap to avoid iterating over them unnecessarily.
The Self: Sized bound is for object safety. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more