Struct cumulus_primitives_core::relay_chain::v1::OccupiedCore [−][src]
pub struct OccupiedCore<H = H256, N = u32> {
pub next_up_on_available: Option<ScheduledCore>,
pub occupied_since: N,
pub time_out_at: N,
pub next_up_on_time_out: Option<ScheduledCore>,
pub availability: BitVec<Lsb0, u8>,
pub group_responsible: GroupIndex,
pub candidate_hash: CandidateHash,
pub candidate_descriptor: CandidateDescriptor<H>,
}Expand description
Information about a core which is currently occupied.
Fields
next_up_on_available: Option<ScheduledCore>If this core is freed by availability, this is the assignment that is next up on this core, if any. None if there is nothing queued for this core.
occupied_since: NThe relay-chain block number this began occupying the core at.
time_out_at: NThe relay-chain block this will time-out at, if any.
next_up_on_time_out: Option<ScheduledCore>If this core is freed by being timed-out, this is the assignment that is next up on this core. None if there is nothing queued for this core or there is no possibility of timing out.
availability: BitVec<Lsb0, u8>A bitfield with 1 bit for each validator in the set. 1 bits mean that the corresponding
validators has attested to availability on-chain. A 2/3+ majority of 1 bits means that
this will be available.
group_responsible: GroupIndexThe group assigned to distribute availability pieces of this candidate.
candidate_hash: CandidateHashThe hash of the candidate occupying the core.
candidate_descriptor: CandidateDescriptor<H>The descriptor of the candidate occupying the core.
Implementations