Struct cumulus_primitives_core::AbridgedHostConfiguration [−][src]
pub struct AbridgedHostConfiguration {
pub max_code_size: u32,
pub max_head_data_size: u32,
pub max_upward_queue_count: u32,
pub max_upward_queue_size: u32,
pub max_upward_message_size: u32,
pub max_upward_message_num_per_candidate: u32,
pub hrmp_max_message_num_per_candidate: u32,
pub validation_upgrade_frequency: u32,
pub validation_upgrade_delay: u32,
}Expand description
Abridged version of HostConfiguration (from the Configuration parachains host runtime module)
meant to be used by a parachain or PDK such as cumulus.
Fields
max_code_size: u32The maximum validation code size, in bytes.
max_head_data_size: u32The maximum head-data size, in bytes.
max_upward_queue_count: u32Total number of individual messages allowed in the parachain -> relay-chain message queue.
max_upward_queue_size: u32Total size of messages allowed in the parachain -> relay-chain message queue before which no further messages may be added to it. If it exceeds this then the queue may contain only a single message.
max_upward_message_size: u32The maximum size of an upward message that can be sent by a candidate.
This parameter affects the size upper bound of the CandidateCommitments.
max_upward_message_num_per_candidate: u32The maximum number of messages that a candidate can contain.
This parameter affects the size upper bound of the CandidateCommitments.
hrmp_max_message_num_per_candidate: u32The maximum number of outbound HRMP messages can be sent by a candidate.
This parameter affects the upper bound of size of CandidateCommitments.
validation_upgrade_frequency: u32The minimum frequency at which parachains can update their validation code.
validation_upgrade_delay: u32The delay, in blocks, before a validation upgrade is applied.